@@ -37,7 +37,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use App::Dochazka::Common::Model;
-use constant ATTRS => qw( cid path source acl parameters );
+use constant ATTRS => qw( cid path source acl validations );
 
 BEGIN {
     App::Dochazka::Common::Model::boilerplate( __PACKAGE__, ATTRS );
